
if (CMAKE_VERSION VERSION_LESS 2.8.3)
    message(FATAL_ERROR "Qt 5 requires at least CMake version 2.8.3")
endif()

get_filename_component(_qt5Svg_install_prefix "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# For backwards compatibility only. Use Qt5Svg_VERSION instead.
set(Qt5Svg_VERSION_STRING 5.9.1)

set(Qt5Svg_LIBRARIES Qt5::Svg)

macro(_qt5_Svg_check_file_exists file)
    if(NOT EXISTS "${file}" )
        message(FATAL_ERROR "The imported target \"Qt5::Svg\" references the file
   \"${file}\"
but this file does not exist.  Possible reasons include:
* The file was deleted, renamed, or moved to another location.
* An install or uninstall procedure did not complete successfully.
* The installation package was faulty and contained
   \"${CMAKE_CURRENT_LIST_FILE}\"
but not all the files it references.
")
    endif()
endmacro()

macro(_populate_Svg_target_properties TARGET_CONFIG LIB_LOCATION IMPLIB_LOCATION)
    set_property(TARGET Qt5::Svg APPEND PROPERTY IMPORTED_CONFIGURATIONS ${TARGET_CONFIG})

    set(imported_location "${_qt5Svg_install_prefix}/lib/${LIB_LOCATION}")

    _qt5_Svg_check_file_exists(${imported_location})

    if (_Qt5Svg_LIB_DEPENDENCIES)
        set(_list_sep ";")
    endif()
    set_target_properties(Qt5::Svg PROPERTIES
        "INTERFACE_LINK_LIBRARIES_${TARGET_CONFIG}" "${_Qt5Svg_LIB_DEPENDENCIES}${_list_sep}${_Qt5Svg_STATIC_${TARGET_CONFIG}_LIB_DEPENDENCIES}"
        "IMPORTED_LOCATION_${TARGET_CONFIG}" ${imported_location}
        # For backward compatibility with CMake < 2.8.12
        "IMPORTED_LINK_INTERFACE_LIBRARIES_${TARGET_CONFIG}" "${_Qt5Svg_LIB_DEPENDENCIES}${_list_sep}${_Qt5Svg_STATIC_${TARGET_CONFIG}_LIB_DEPENDENCIES}"
    )

endmacro()

if (NOT TARGET Qt5::Svg)

    set(_Qt5Svg_OWN_INCLUDE_DIRS "${_qt5Svg_install_prefix}/include/qt/" "${_qt5Svg_install_prefix}/include/qt/QtSvg")
    set(Qt5Svg_PRIVATE_INCLUDE_DIRS "")
    include("${CMAKE_CURRENT_LIST_DIR}/ExtraSourceIncludes.cmake" OPTIONAL)

    foreach(_dir ${_Qt5Svg_OWN_INCLUDE_DIRS})
        _qt5_Svg_check_file_exists(${_dir})
    endforeach()

    # Only check existence of private includes if the Private component is
    # specified.
    list(FIND Qt5Svg_FIND_COMPONENTS Private _check_private)
    if (NOT _check_private STREQUAL -1)
        foreach(_dir ${Qt5Svg_PRIVATE_INCLUDE_DIRS})
            _qt5_Svg_check_file_exists(${_dir})
        endforeach()
    endif()

    set(Qt5Svg_INCLUDE_DIRS ${_Qt5Svg_OWN_INCLUDE_DIRS})

    set(Qt5Svg_DEFINITIONS -DQT_SVG_LIB)
    set(Qt5Svg_COMPILE_DEFINITIONS QT_SVG_LIB)
    set(_Qt5Svg_MODULE_DEPENDENCIES "Widgets;Gui;Core")


    set(Qt5Svg_OWN_PRIVATE_INCLUDE_DIRS ${Qt5Svg_PRIVATE_INCLUDE_DIRS})

    set(_Qt5Svg_FIND_DEPENDENCIES_REQUIRED)
    if (Qt5Svg_FIND_REQUIRED)
        set(_Qt5Svg_FIND_DEPENDENCIES_REQUIRED REQUIRED)
    endif()
    set(_Qt5Svg_FIND_DEPENDENCIES_QUIET)
    if (Qt5Svg_FIND_QUIETLY)
        set(_Qt5Svg_DEPENDENCIES_FIND_QUIET QUIET)
    endif()
    set(_Qt5Svg_FIND_VERSION_EXACT)
    if (Qt5Svg_FIND_VERSION_EXACT)
        set(_Qt5Svg_FIND_VERSION_EXACT EXACT)
    endif()

    set(Qt5Svg_EXECUTABLE_COMPILE_FLAGS "")

    foreach(_module_dep ${_Qt5Svg_MODULE_DEPENDENCIES})
        if (NOT Qt5${_module_dep}_FOUND)
            find_package(Qt5${_module_dep}
                5.9.1 ${_Qt5Svg_FIND_VERSION_EXACT}
                ${_Qt5Svg_DEPENDENCIES_FIND_QUIET}
                ${_Qt5Svg_FIND_DEPENDENCIES_REQUIRED}
                PATHS "${CMAKE_CURRENT_LIST_DIR}/.." NO_DEFAULT_PATH
            )
        endif()

        if (NOT Qt5${_module_dep}_FOUND)
            set(Qt5Svg_FOUND False)
            return()
        endif()

        list(APPEND Qt5Svg_INCLUDE_DIRS "${Qt5${_module_dep}_INCLUDE_DIRS}")
        list(APPEND Qt5Svg_PRIVATE_INCLUDE_DIRS "${Qt5${_module_dep}_PRIVATE_INCLUDE_DIRS}")
        list(APPEND Qt5Svg_DEFINITIONS ${Qt5${_module_dep}_DEFINITIONS})
        list(APPEND Qt5Svg_COMPILE_DEFINITIONS ${Qt5${_module_dep}_COMPILE_DEFINITIONS})
        list(APPEND Qt5Svg_EXECUTABLE_COMPILE_FLAGS ${Qt5${_module_dep}_EXECUTABLE_COMPILE_FLAGS})
    endforeach()
    list(REMOVE_DUPLICATES Qt5Svg_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5Svg_PRIVATE_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5Svg_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt5Svg_COMPILE_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt5Svg_EXECUTABLE_COMPILE_FLAGS)

    set(_Qt5Svg_LIB_DEPENDENCIES "Qt5::Widgets;Qt5::Gui;Qt5::Core")


    add_library(Qt5::Svg STATIC IMPORTED)
    set_property(TARGET Qt5::Svg PROPERTY IMPORTED_LINK_INTERFACE_LANGUAGES CXX)
    macro(_process_prl_file PRL_FILE_LOCATION CONFIGURATION)
        if (EXISTS "${PRL_FILE_LOCATION}")
            file(STRINGS "${PRL_FILE_LOCATION}" prl_strings REGEX "QMAKE_PRL_LIBS_FOR_CMAKE")
            string(REGEX REPLACE "QMAKE_PRL_LIBS_FOR_CMAKE *= *([^\n]*)" "\\1" static_depends ${prl_strings})
            string(REGEX REPLACE "\\$\\$\\[QT_INSTALL_LIBS\\]" "${_qt5Svg_install_prefix}/lib" static_depends "${static_depends}")
            string(REPLACE "-framework;" "-framework " static_depends "${static_depends}")
            if (_Qt5Svg_STATIC_${CONFIGURATION}_LIB_DEPENDENCIES)
                set(_list_sep ";")
            endif()
            set(_Qt5Svg_STATIC_${CONFIGURATION}_LIB_DEPENDENCIES "${_Qt5Svg_STATIC_${CONFIGURATION}_LIB_DEPENDENCIES}${_list_sep}${static_depends}")
        endif()
    endmacro()

    macro(_process_plugin_prl_file PRL_FILE_LOCATION CONFIGURATION LIB_DIRECTORY LIB_LOCATION)
        # First add the (static) plugin itself ...
        if (_Qt5Svg_STATIC_${CONFIGURATION}_LIB_DEPENDENCIES)
            set(_list_sep ";")
        endif()
        set(_Qt5Svg_STATIC_${CONFIGURATION}_LIB_DEPENDENCIES "${_Qt5Svg_STATIC_${CONFIGURATION}_LIB_DEPENDENCIES}${_list_sep}${_qt5Svg_install_prefix}/${LIB_DIRECTORY}/${LIB_LOCATION}")
        # .. then its dependencies.
        _process_prl_file(${PRL_FILE_LOCATION} ${CONFIGURATION})
    endmacro()

    _process_prl_file("${_qt5Svg_install_prefix}/lib/libQt5Svg_debug.prl" DEBUG)
    _process_prl_file("${_qt5Svg_install_prefix}/lib/libQt5Svg.prl" RELEASE)



    set_property(TARGET Qt5::Svg PROPERTY
      INTERFACE_INCLUDE_DIRECTORIES ${_Qt5Svg_OWN_INCLUDE_DIRS})
    set_property(TARGET Qt5::Svg PROPERTY
      INTERFACE_COMPILE_DEFINITIONS QT_SVG_LIB)

    # Find plugin targets
    file(GLOB pluginTargetsMaybe "${CMAKE_CURRENT_LIST_DIR}/*Qt5Svg_*.cmake")
    unset(pluginTargets)
    if(pluginTargetsMaybe)
        foreach(pluginTarget ${pluginTargetsMaybe})
            file(STRINGS ${pluginTarget} matched REGEX Qt5Svg_PLUGINS)
            if(matched)
                list(APPEND pluginTargets ${pluginTarget})
            endif()
        endforeach()
    endif()

    macro(_populate_Svg_plugin_properties TARGET_NAME PLUGIN_TARGET_NAME PLUGIN_NAME CONFIG PLUGIN_LOCATION)
        set_property(TARGET ${PLUGIN_TARGET_NAME} APPEND PROPERTY IMPORTED_CONFIGURATIONS ${CONFIG})

        set(imported_location "${_qt5Svg_install_prefix}/lib/qt/plugins/${PLUGIN_LOCATION}")
        _qt5_Svg_check_file_exists(${imported_location})
        set_target_properties(${PLUGIN_TARGET_NAME} PROPERTIES
            "IMPORTED_LOCATION_${CONFIG}" ${imported_location}
        )
            set_property(TARGET ${TARGET_NAME} APPEND PROPERTY STATIC_PLUGINS ${PLUGIN_NAME})
            get_filename_component(_PLUGIN_DIR ${PLUGIN_LOCATION} PATH)
            get_filename_component(_PLUGIN_DIR_NAME ${_PLUGIN_DIR} NAME)
            get_filename_component(_PLUGIN_NAME ${PLUGIN_LOCATION} NAME)
            string(REGEX REPLACE "^lib(.*)\\.a" "${_qt5Svg_install_prefix}/lib/qt/plugins/${_PLUGIN_DIR_NAME}/\\1.prl" PLUGIN_PRL_FILE_LOCATION ${_PLUGIN_NAME})
            if(NOT EXISTS ${PLUGIN_PRL_FILE_LOCATION})
                string(REGEX REPLACE "^lib(.*)\\.a" "${_qt5Svg_install_prefix}/lib/qt/plugins/${_PLUGIN_DIR_NAME}/\\1.static.prl" PLUGIN_PRL_FILE_LOCATION ${_PLUGIN_NAME})
            endif()
            if(NOT EXISTS ${PLUGIN_PRL_FILE_LOCATION})
                string(REGEX REPLACE "^lib(.*)\\.a" "${_qt5Svg_install_prefix}/lib/qt/plugins/${_PLUGIN_DIR_NAME}/lib\\1.prl" PLUGIN_PRL_FILE_LOCATION ${_PLUGIN_NAME})
            endif()
            if(NOT EXISTS ${PLUGIN_PRL_FILE_LOCATION})
                message(FATAL_ERROR The prl file containing dependencies of static plugin ${PLUGIN_TARGET_NAME} of ${TARGET_NAME} could not be found.)
            endif()
            _process_plugin_prl_file(${PLUGIN_PRL_FILE_LOCATION} ${CONFIG} "lib/qt/plugins" ${PLUGIN_LOCATION})

    endmacro()

    if(pluginTargets)
        foreach(pluginTarget ${pluginTargets})
            include(${pluginTarget})
        endforeach()
    endif()

    set(_Qt5Svg_PRIVATE_DIRS_EXIST TRUE)
    foreach (_Qt5Svg_PRIVATE_DIR ${Qt5Svg_OWN_PRIVATE_INCLUDE_DIRS})
        if (NOT EXISTS ${_Qt5Svg_PRIVATE_DIR})
            set(_Qt5Svg_PRIVATE_DIRS_EXIST FALSE)
        endif()
    endforeach()

    if (_Qt5Svg_PRIVATE_DIRS_EXIST
        AND NOT CMAKE_VERSION VERSION_LESS 3.0.0 )
        add_library(Qt5::SvgPrivate INTERFACE IMPORTED)
        set_property(TARGET Qt5::SvgPrivate PROPERTY
            INTERFACE_INCLUDE_DIRECTORIES ${Qt5Svg_OWN_PRIVATE_INCLUDE_DIRS}
        )
        set(_Qt5Svg_PRIVATEDEPS)
        foreach(dep ${_Qt5Svg_LIB_DEPENDENCIES})
            if (TARGET ${dep}Private)
                list(APPEND _Qt5Svg_PRIVATEDEPS ${dep}Private)
            endif()
        endforeach()
        set_property(TARGET Qt5::SvgPrivate PROPERTY
            INTERFACE_LINK_LIBRARIES Qt5::Svg ${_Qt5Svg_PRIVATEDEPS}
        )
    endif()

    _populate_Svg_target_properties(RELEASE "libQt5Svg.a" "" )






_qt5_Svg_check_file_exists("${CMAKE_CURRENT_LIST_DIR}/Qt5SvgConfigVersion.cmake")

endif()
